==> mob_variants_api_zenxarch-0.0.1-sources.jar: org/codeberg/zenxarch/mob_variants_api/client/mixin/LivingEntityRendererMixin.java <==
package org.codeberg.zenxarch.mob_variants_api.client.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_10042;
import net.minecraft.class_12079.class_10726;
import net.minecraft.class_1309;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_922;
import org.codeberg.zenxarch.mob_variants_api.client.ExtendedRenderState;
import org.codeberg.zenxarch.mob_variants_api.variant.MobAttachments;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Environment(EnvType.CLIENT)
@Mixin(class_922.class)
public abstract class LivingEntityRendererMixin {

  @Unique private class_2960 zenxarch$texture_override = null;

  @WrapOperation(
      method = "getRenderLayer",
      at =
          @At(
              value = "INVOKE",
              target =
                  "Lnet/minecraft/client/render/entity/LivingEntityRenderer;getTexture(Lnet/minecraft/client/render/entity/state/LivingEntityRenderState;)Lnet/minecraft/util/Identifier;"))
  private class_2960 zenxarch$modifyTexture(
      class_922<?, ?, ?> self,
      class_10042 renderState,
      Operation<class_2960> op) {
    if (this.zenxarch$texture_override != null
        && class_310.method_1551()
            .method_1478()
            .method_14486(zenxarch$texture_override)
            .isPresent()) return this.zenxarch$texture_override;
    return op.call(self, renderState);
  }

  @Inject(
      method =
          "updateRenderState(Lnet/minecraft/entity/LivingEntity;Lnet/minecraft/client/render/entity/state/LivingEntityRenderState;F)V",
      at = @At("HEAD"))
  private void zenxarch$tryGetTextureOverride(
      class_1309 livingEntity,
      class_10042 livingEntityRenderState,
      float f,
      CallbackInfo ci) {
    this.zenxarch$texture_override =
        livingEntity
            .getAttachedOrElse(MobAttachments.TEXTURE_OVERRIDE, new class_10726(null, null))
            .comp_3627();
    if (livingEntityRenderState instanceof ExtendedRenderState exState)
      exState.zenxarch$setHideHead(
          !livingEntity.getAttachedOrElse(MobAttachments.RENDER_HEAD, true));
  }
}

==> mob_variants_api_zenxarch-0.0.2-sources.jar: org/codeberg/zenxarch/mob_variants_api/client/mixin/LivingEntityRendererMixin.java <==
package org.codeberg.zenxarch.mob_variants_api.client.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_10042;
import net.minecraft.class_1309;
import net.minecraft.class_2960;
import net.minecraft.class_922;
import org.codeberg.zenxarch.mob_variants_api.client.ExtendedRenderStateDataKeys;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Environment(EnvType.CLIENT)
@Mixin(class_922.class)
public abstract class LivingEntityRendererMixin {

  @WrapOperation(
      method = "getRenderLayer",
      at =
          @At(
              value = "INVOKE",
              target =
                  "Lnet/minecraft/client/render/entity/LivingEntityRenderer;getTexture(Lnet/minecraft/client/render/entity/state/LivingEntityRenderState;)Lnet/minecraft/util/Identifier;"))
  private class_2960 zenxarch$modifyTexture(
      class_922<?, ?, ?> self,
      class_10042 renderState,
      Operation<class_2960> op) {
    return ExtendedRenderStateDataKeys.TEXTURE_OVERRIDE
        .get(renderState)
        .orElse(op.call(self, renderState));
  }

  @Inject(
      method =
          "updateRenderState(Lnet/minecraft/entity/LivingEntity;Lnet/minecraft/client/render/entity/state/LivingEntityRenderState;F)V",
      at = @At("HEAD"))
  private void zenxarch$tryGetTextureOverride(
      class_1309 livingEntity,
      class_10042 livingEntityRenderState,
      float f,
      CallbackInfo ci) {
    ExtendedRenderStateDataKeys.TEXTURE_OVERRIDE.set(livingEntity, livingEntityRenderState);
    ExtendedRenderStateDataKeys.RENDER_HEAD.set(livingEntity, livingEntityRenderState);
  }
}
